@@ -1,7 +1,7 @@
 // qsynthEngine.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2004, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -13,9 +13,9 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 *****************************************************************************/
 
@@ -29,65 +29,65 @@
 // Constructor.
 qsynthEngine::qsynthEngine ( qsynthOptions *pOptions, const QString& sName )
 {
-    // We're the default (first) engine whether we've given a name...
-    m_bDefault = sName.isEmpty();
-    if (m_bDefault) {
-        m_pSetup = pOptions->defaultSetup();
-    } else {
-        m_pSetup = new qsynthSetup();
-        pOptions->loadSetup(m_pSetup, sName);
-    }
+	// We're the default (first) engine whether we've given a name...
+	m_bDefault = sName.isEmpty();
+	if (m_bDefault) {
+		m_pSetup = pOptions->defaultSetup();
+	} else {
+		m_pSetup = new qsynthSetup();
+		pOptions->loadSetup(m_pSetup, sName);
+	}
 
-    // From now on, we must have a name.
-    m_sName = m_pSetup->sDisplayName;
+	// From now on, we must have a name.
+	m_sName = m_pSetup->sDisplayName;
 
-    pSynth       = NULL;
-    pAudioDriver = NULL;
-    pMidiRouter  = NULL;
-    pMidiDriver  = NULL;
-    pPlayer      = NULL;
-    pServer      = NULL;
+	pSynth       = NULL;
+	pAudioDriver = NULL;
+	pMidiRouter  = NULL;
+	pMidiDriver  = NULL;
+	pPlayer      = NULL;
+	pServer      = NULL;
 
-    iMidiEvent = 0;
-    iMidiState = 0;
+	iMidiEvent = 0;
+	iMidiState = 0;
 
-    bMeterEnabled  = false;
-    fMeterValue[0] = 0.0;
-    fMeterValue[1] = 0.0;
+	bMeterEnabled  = false;
+	fMeterValue[0] = 0.0f;
+	fMeterValue[1] = 0.0f;
 }
 
 
 // Default destructor.
 qsynthEngine::~qsynthEngine (void)
 {
-    if (!m_bDefault && m_pSetup) {
-        delete m_pSetup;
-        m_pSetup = NULL;
-    }
+	if (!m_bDefault && m_pSetup) {
+		delete m_pSetup;
+		m_pSetup = NULL;
+	}
 }
 
 // Engine predicate.
-bool qsynthEngine::isDefault (void)
+bool qsynthEngine::isDefault (void) const
 {
-    return m_bDefault;
+	return m_bDefault;
 }
 
 
 // Engine setup accessor.
 qsynthSetup *qsynthEngine::setup (void)
 {
-    return m_pSetup;
+	return m_pSetup;
 }
 
 // Engine name accessors.
-const QString& qsynthEngine::name (void)
+const QString& qsynthEngine::name (void) const
 {
-    return m_sName;
+	return m_sName;
 }
 
 void qsynthEngine::setName ( const QString& sName )
 {
-    m_sName = sName;
+	m_sName = sName;
 }
 
 
