@@ -29,9 +29,13 @@
 class qsynthOptions;
 class qsynthMessagesForm;
 class qsynthChannelsForm;
+
+#ifdef CONFIG_SYSTEM_TRAY
 class qsynthSystemTray;
+#endif
 
 class QSocketNotifier;
+class QSessionManager;
 class QMimeSource;
 
 
@@ -72,16 +76,13 @@ public:
 
 	enum KnobStyle { Classic, Vokimon, Peppino, Skulpture, Legacy };
 
-	void setQuitForce(bool bQuitForce);
-	bool isQuitForce() const;
-
 public slots:
 
 	void stdoutNotifySlot(int);
 	void appendStdoutBuffer(const QString&);
 	void flushStdoutBuffer();
 
-	void systemTrayContextMenu(const QPoint&);
+	void contextMenu(const QPoint&);
 
 	void stabilizeForm();
 
@@ -117,6 +118,8 @@ public slots:
 
 	void quitMainForm();
 
+	void commitData(QSessionManager& sm);
+
 protected:
 
 	bool queryClose();
@@ -132,7 +135,9 @@ protected:
 	void updateMessagesFont();
 	void updateMessagesLimit();
 	void updateOutputMeters();
+#ifdef CONFIG_SYSTEM_TRAY
 	void updateSystemTray();
+#endif
 
 	qsynthEngine *currentEngine() const;
 
@@ -184,8 +189,11 @@ private:
 
 	QString m_sStdoutBuffer;
 
+#ifdef CONFIG_SYSTEM_TRAY
 	qsynthSystemTray *m_pSystemTray;
 	int m_iSystemTrayState;
+	bool m_bQuitClose;
+#endif
 
 	bool m_bQuitForce;
 
