@@ -1,7 +1,7 @@
 // qsynthPresetForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,12 +22,6 @@
 #ifndef __qsynthPresetForm_h
 #define __qsynthPresetForm_h
 
-#include <QtGlobal>
-
-#if QT_VERSION < 0x040200
-#define setAllColumnsShowFocus(x) parent()
-#endif
-
 #include "ui_qsynthPresetForm.h"
 
 #include <fluidsynth.h>
