@@ -1,7 +1,7 @@
 // qsynthSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -841,11 +841,7 @@ void qsynthSetupForm::openSoundFont (void)
 			if (pItem == NULL) {
 				pItem = m_ui.SoundFontListView->currentItem();
 				if (pItem)
-			#if QT_VERSION >= 0x040200
 					pItem->setSelected(false);
-			#else
-					m_ui.SoundFontListView->setItemSelected(pItem, false);
-			#endif
 			}
 			// New item on the block :-)
 			pItem = new QTreeWidgetItem(m_ui.SoundFontListView, pItem);
@@ -856,11 +852,7 @@ void qsynthSetupForm::openSoundFont (void)
 				pItem->setText(2, "0");
 				pItem->setFlags(pItem->flags() | Qt::ItemIsEditable);
 			#endif
-			#if QT_VERSION >= 0x040200
 				pItem->setSelected(true);
-			#else
-				m_ui.SoundFontListView->setItemSelected(pItem, true);
-			#endif
 				m_ui.SoundFontListView->setCurrentItem(pItem);
 				m_pOptions->sSoundFontDir = QFileInfo(sSoundFont).dir().absolutePath();
 				++m_iDirtyCount;
@@ -912,18 +904,10 @@ void qsynthSetupForm::moveUpSoundFont (void)
 	if (pItem) {
 		int iItem = m_ui.SoundFontListView->indexOfTopLevelItem(pItem);
 		if (iItem > 0) {
-		#if QT_VERSION >= 0x040200
 			pItem->setSelected(false);
-		#else
-			m_ui.SoundFontListView->setItemSelected(pItem, false);
-		#endif
 			pItem = m_ui.SoundFontListView->takeTopLevelItem(iItem);
 			m_ui.SoundFontListView->insertTopLevelItem(iItem - 1, pItem);
-		#if QT_VERSION >= 0x040200
 			pItem->setSelected(true);
-		#else
-			m_ui.SoundFontListView->setItemSelected(pItem, true);
-		#endif
 			m_ui.SoundFontListView->setCurrentItem(pItem);
 			++m_iDirtyCount;
 		}
@@ -942,18 +926,10 @@ void qsynthSetupForm::moveDownSoundFont (void)
 		int iItem = m_ui.SoundFontListView->indexOfTopLevelItem(pItem);
 		int iItemCount = m_ui.SoundFontListView->topLevelItemCount();
 		if (iItem < iItemCount - 1) {
-		#if QT_VERSION >= 0x040200
 			pItem->setSelected(false);
-		#else
-			m_ui.SoundFontListView->setItemSelected(pItem, false);
-		#endif
 			pItem = m_ui.SoundFontListView->takeTopLevelItem(iItem);
 			m_ui.SoundFontListView->insertTopLevelItem(iItem + 1, pItem);
-		#if QT_VERSION >= 0x040200
 			pItem->setSelected(true);
-		#else
-			m_ui.SoundFontListView->setItemSelected(pItem, true);
-		#endif
 			m_ui.SoundFontListView->setCurrentItem(pItem);
 			m_iDirtyCount++;
 		}
